"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SPBuildTasks = void 0;
var gulp_load_plugins_1 = __importDefault(require("gulp-load-plugins"));
var fs = __importStar(require("fs"));
var path = __importStar(require("path"));
var config_1 = require("./tasks/config");
var sync_1 = require("./tasks/sync");
var deploy_1 = require("./tasks/deploy");
var build_1 = require("./tasks/build");
var watch_1 = require("./tasks/watch");
var clean_1 = require("./tasks/clean");
var analyze_1 = require("./tasks/analyze");
var features_1 = require("./tasks/features");
var serve_1 = require("./tasks/serve");
var SPBuildTasks = (function () {
    function SPBuildTasks(gulp, settings) {
        if (settings === void 0) { settings = {}; }
        this.settings = __assign(__assign({}, settings), { appConfig: settings.appConfig || './config/app.json', privateConf: settings.privateConf || './config/private.json', taskPath: settings.taskPath || './build/tasks' });
        this.gulp = gulp;
        this.initDotEnv();
        this.initGulpTasks();
    }
    SPBuildTasks.prototype.initDotEnv = function () {
        var envPath = path.join(process.cwd(), '.env');
        if (!fs.existsSync(envPath)) {
            fs.writeFileSync(envPath, "PRIVATE_JSON=./config/private.json\n" +
                "TASKS_PATH=./tools/tasks\n" +
                "APP_JSON=./config/app.json\n" +
                "SPBUILD_WEBPACK_PORT=9090\n" +
                "SPPP_ASSETS_LOCATION=SPWeb", { encoding: 'utf-8' });
        }
    };
    SPBuildTasks.prototype.initGulpTasks = function () {
        var plugins = this.loadGulpPlugins();
        this.loadSPBuildGulpPlugins(plugins);
        if (this.settings.taskPath) {
            this.loadCustomGulpTasks(this.settings.taskPath, plugins, this.settings);
        }
    };
    SPBuildTasks.prototype.loadSPBuildGulpPlugins = function (plugins) {
        if (typeof plugins === 'undefined') {
            plugins = this.loadGulpPlugins();
        }
        (0, config_1.configTasks)(this.gulp, plugins, this.settings);
        (0, sync_1.syncTasks)(this.gulp, plugins, this.settings);
        (0, deploy_1.deployTasks)(this.gulp, plugins, this.settings);
        (0, build_1.buildTasks)(this.gulp, plugins, this.settings);
        (0, watch_1.watchTasks)(this.gulp, plugins, this.settings);
        (0, clean_1.cleanTasks)(this.gulp, plugins, this.settings);
        (0, analyze_1.analyzeTasks)(this.gulp, plugins, this.settings);
        (0, features_1.featuresTasks)(this.gulp, plugins, this.settings);
        (0, serve_1.serveTasks)(this.gulp, plugins, this.settings);
    };
    SPBuildTasks.prototype.loadCustomGulpTasks = function (taskPath, plugins, settings) {
        var _this = this;
        if (fs.existsSync(taskPath)) {
            var taskList = fs.readdirSync(taskPath);
            if (typeof plugins === 'undefined') {
                plugins = this.loadGulpPlugins();
            }
            taskList.forEach(function (taskFile) {
                if (taskFile !== 'customDataLoader.js') {
                    var task = require(path.resolve(path.join(taskPath, taskFile)));
                    if (task && typeof task === 'function') {
                        task(_this.gulp, plugins, settings);
                    }
                }
            });
        }
    };
    SPBuildTasks.prototype.loadGulpPlugins = function () {
        return (0, gulp_load_plugins_1.default)({
            pattern: [
                'gulp-*', 'gulp.*', 'del', 'through2'
            ],
            rename: {
                'through2': 'through'
            }
        });
    };
    return SPBuildTasks;
}());
exports.SPBuildTasks = SPBuildTasks;
//# sourceMappingURL=SPBuildTasks.js.map