"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.configTasks = exports.getConfigs = void 0;
var path = __importStar(require("path"));
var fs = __importStar(require("fs"));
var node_sp_auth_config_1 = require("node-sp-auth-config");
var minimist_1 = __importDefault(require("minimist"));
var misc_1 = require("../utils/misc");
var getConfigsData = function (settings, forcePrompts) {
    if (forcePrompts === void 0) { forcePrompts = false; }
    var args = process.argv.slice(3);
    var params = (0, minimist_1.default)(args);
    var mapGulpConfigs = function (appConfig, privateConfig) {
        var siteUrl = (0, misc_1.parseObjectChain)(function () { return params.privateConfig.siteUrl; }) || privateConfig.siteUrl;
        var gulpConfigs = {
            appConfig: __assign(__assign({}, appConfig), { masterpageCodeName: appConfig.masterpageCodeName || 'Frankfurt', deleteFiles: typeof appConfig.deleteFiles !== 'undefined' ? appConfig.deleteFiles : false }),
            privateConf: {
                siteUrl: siteUrl,
                creds: __assign({}, privateConfig.authOptions)
            },
            spSaveCoreOptions: {
                siteUrl: siteUrl,
                folder: appConfig.spFolder,
                flatten: false,
                checkin: true,
                checkinType: 1,
                filesMetaData: appConfig.filesMetaData
            },
            watch: {
                assets: path.resolve(appConfig.distFolder) + '/**/*.*',
                base: path.resolve(appConfig.distFolder)
            },
            liveReload: {
                siteUrl: siteUrl,
                protocol: siteUrl.indexOf('https://') !== -1 ? 'https' : 'http',
                host: 'localhost',
                port: 3000,
                watchBase: path.join(process.cwd(), appConfig.distFolder.replace('./', '')),
                spFolder: appConfig.spFolder,
                ssl: {
                    key: path.join(process.cwd(), './config/ssl/key.pem'),
                    cert: path.join(process.cwd(), '/config/ssl/cert.crt')
                },
                creds: __assign(__assign({}, privateConfig), privateConfig.authOptions)
            }
        };
        return gulpConfigs;
    };
    return new Promise(function (resolve, reject) {
        global.spBuildAppConfig = global.spBuildAppConfig || require(path.resolve(settings.appConfig || './config/app.json'));
        if (typeof global.spBuildContext === 'undefined') {
            var authConfig = new node_sp_auth_config_1.AuthConfig({
                configPath: path.resolve(settings.privateConf || './config/private.json'),
                encryptPassword: true,
                saveConfigOnDisk: true,
                forcePrompts: forcePrompts,
                headlessMode: !forcePrompts
            });
            authConfig.getContext()
                .then(function (context) {
                global.spBuildContext = context;
                global.gulpConfigs = mapGulpConfigs(global.spBuildAppConfig, global.spBuildContext);
                resolve(global.gulpConfigs);
            })
                .catch(reject);
        }
        else {
            global.gulpConfigs = mapGulpConfigs(global.spBuildAppConfig, global.spBuildContext);
            resolve(global.gulpConfigs);
        }
    });
};
var getCustomData = function (settings, gulpConfigs) {
    return new Promise(function (resolve, reject) {
        if (!settings.taskPath) {
            return reject('No task path is defined');
        }
        var customDataModulePath = path.join(process.cwd(), settings.taskPath, 'customDataLoader.js');
        if (fs.existsSync(customDataModulePath)) {
            var customDataLoader = require(customDataModulePath);
            if (customDataLoader && typeof customDataLoader === 'function') {
                customDataLoader(settings, gulpConfigs)
                    .then(function (customData) {
                    global.gulpConfigs = __assign(__assign({}, gulpConfigs), { appConfig: __assign(__assign({}, gulpConfigs.appConfig), { customData: __assign({}, (customData || {})) }) });
                    resolve(global.gulpConfigs);
                })
                    .catch(function (err) {
                    console.log(err);
                    resolve(gulpConfigs);
                });
            }
        }
        else {
            resolve(gulpConfigs);
        }
    });
};
var getConfigs = function (settings, force) {
    if (force === void 0) { force = false; }
    return getConfigsData(settings, force).then(function (conf) { return getCustomData(settings, conf); });
};
exports.getConfigs = getConfigs;
var execConfigTask = function (settings, force, cb) {
    (0, exports.getConfigs)(settings, force).then(function () { return cb(); }).catch(cb);
};
var configTasks = function (gulp, $, settings) {
    gulp.task('config', function (cb) {
        var args = process.argv.slice(3);
        var force = args.filter(function (arg) { return arg.toLowerCase() === '--init'; }).length > 0;
        execConfigTask(settings, force, cb);
    });
};
exports.configTasks = configTasks;
//# sourceMappingURL=config.js.map