"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var sp_request_1 = require("sp-request");
var Deploy = (function () {
    function Deploy(settings) {
        this.settings = __assign({}, settings);
    }
    Deploy.prototype.applyMasterpageToWeb = function (params) {
        if (params === void 0) { params = {}; }
        var webUrl = params.webUrl || this.settings.siteUrl;
        var spFolder = params.spFolder || this.settings.spFolder || '';
        var masterpagePath = params.masterpagePath || '';
        var request = (0, sp_request_1.create)(this.settings.creds);
        return new Promise(function (resolve, reject) {
            if (spFolder.length === 0) {
                reject('Error: SharePoint root folder is not provided');
            }
            if (masterpagePath.length === 0) {
                reject('Error: SharePoint masterpage path is not provided');
            }
            var methodUri = "".concat(webUrl, "/_api/web");
            var webRelativeUrl = "/".concat(webUrl.replace('https://', '').replace('http://', '').split('/').splice(1).join('/'));
            var masterpageFullPath = "".concat(webRelativeUrl, "/").concat(spFolder, "/").concat(masterpagePath).replace(/\/\//g, '/');
            request.requestDigest(webUrl)
                .then(function (digest) {
                return request.post(methodUri, {
                    headers: {
                        'X-RequestDigest': digest,
                        'X-HTTP-Method': 'MERGE',
                        'Accept': 'application/json; odata=verbose',
                        'Content-Type': 'application/json; odata=verbose'
                    },
                    body: {
                        '__metadata': { 'type': 'SP.Web' },
                        'MasterUrl': masterpageFullPath,
                        'CustomMasterUrl': masterpageFullPath
                    }
                });
            })
                .then(function () {
                resolve(masterpageFullPath);
            })
                .catch(reject);
        });
    };
    Deploy.prototype.applyLogotypeToWeb = function (params) {
        if (params === void 0) { params = {}; }
        var webUrl = params.webUrl || this.settings.siteUrl;
        var spFolder = params.spFolder || this.settings.spFolder || '';
        var logoPath = params.logoPath || '';
        var request = (0, sp_request_1.create)(this.settings.creds);
        return new Promise(function (resolve, reject) {
            if (spFolder.length === 0) {
                reject('Error: SharePoint root folder is not provided');
            }
            if (logoPath.length === 0) {
                reject('Error: SharePoint logotype path is not provided');
            }
            var methodUri = "".concat(webUrl, "/_api/web");
            var webRelativeUrl = "/".concat(webUrl.replace('https://', '').replace('http://', '').split('/').splice(1).join('/'));
            var logoFullPath = "".concat(webRelativeUrl, "/").concat(spFolder, "/").concat(logoPath).replace(/\/\//g, '/');
            request.requestDigest(webUrl)
                .then(function (digest) {
                return request.post(methodUri, {
                    headers: {
                        'X-RequestDigest': digest,
                        'X-HTTP-Method': 'MERGE',
                        'Accept': 'application/json; odata=verbose',
                        'Content-Type': 'application/json; odata=verbose'
                    },
                    body: {
                        '__metadata': { 'type': 'SP.Web' },
                        'SiteLogoUrl': logoFullPath
                    }
                });
            })
                .then(function () {
                resolve(logoFullPath);
            })
                .catch(reject);
        });
    };
    return Deploy;
}());
exports.default = Deploy;
//# sourceMappingURL=deploy.js.map